API
===

ribocore (*common functions*)
-----------------------------
.. automodule:: riboplot.ribocore
   :members:

riboplot
--------
.. automodule:: riboplot.riboplot
   :members:

ribocount
---------
.. automodule:: riboplot.ribocount
   :members:

config
------
.. automodule:: riboplot.config
   :members:
